==> v0.13.11.tar.gz: git-next/crates/core/src/git/repository/open/tests/commit_log.rs <==
use crate::CommitCount;

//
use super::*;

#[test]
// assumes running in the git-next repo which should have main, next and dev as remote branches
fn should_return_single_item_in_commit_log_when_not_searching() -> TestResult {
    let_assert!(Ok(fs) = kxio::fs::temp());
    let gitdir = GitDir::new(fs.base().to_path_buf(), StoragePathType::Internal);
    let forge_details = given::forge_details();
    let test_repository = git::repository::test(fs.clone(), forge_details);
    let_assert!(Ok(open_repository) = test_repository.open(&gitdir));
    let repo_config = &given::a_repo_config();
    let branches = repo_config.branches();
    then::create_a_commit_on_branch(&fs, &gitdir, &branches.main())?;
    then::create_a_commit_on_branch(&fs, &gitdir, &branches.main())?;
    let_assert!(Ok(result) = open_repository.commit_log(&branches.main(), &[]));
    assert_eq!(result.len(), 1);
    Ok(())
}

#[test]
// assumes running in the git-next repo which should have main, next and dev as remote branches
fn should_return_capacity_25_in_commit_log_when_searching_for_garbage() -> TestResult {
    let_assert!(Ok(fs) = kxio::fs::temp());
    let branch_name = given::a_branch_name();
    let gitdir = GitDir::new(fs.base().to_path_buf(), StoragePathType::Internal);
    let forge_details = given::forge_details().with_max_dev_commits(Some(CommitCount::from(25)));
    let_assert!(Some(max_dev_commits) = forge_details.max_dev_commits());
    assert!(**max_dev_commits >= 25);
    let test_repository = git::repository::test(fs.clone(), forge_details);
    let_assert!(Ok(open_repository) = test_repository.open(&gitdir));
    for _ in [0; 25] {
        then::create_a_commit_on_branch(&fs, &gitdir, &branch_name)?;
    }
    let_assert!(Ok(result) = open_repository.commit_log(&branch_name, &[given::a_commit()]));
    assert_eq!(result.len(), 25);
    Ok(())
}

#[test]
// assumes running in the git-next repo which should have main, next and dev as remote branches
fn should_return_5_in_commit_log_when_searching_for_5th_item() -> TestResult {
    let_assert!(Ok(fs) = kxio::fs::temp(), "create temp directory");
    let branch_name = given::a_branch_name();
    let gitdir = GitDir::new(fs.base().to_path_buf(), StoragePathType::Internal);
    let forge_details = given::forge_details().with_max_dev_commits(Some(CommitCount::from(10)));
    let_assert!(Some(max_dev_commits) = forge_details.max_dev_commits());
    assert!(**max_dev_commits > 5);
    let test_repository = git::repository::test(fs.clone(), forge_details);
    let_assert!(
        Ok(open_repository) = test_repository.open(&gitdir),
        "open repository"
    );
    for _ in [0; 10] {
        then::create_a_commit_on_branch(&fs, &gitdir, &branch_name)?;
    }
    // search to garbage to get all 10 items
    let_assert!(
        Ok(long_list) = open_repository.commit_log(&branch_name, &[given::a_commit()]),
        "get commit_log"
    );
    // pick the 5th item
    let search = &long_list[4]; // zero-based
                                // search for the 25th item
    let_assert!(
        Ok(result) = open_repository.commit_log(&branch_name, &[search.clone()]),
        "get commit log"
    );
    // returns
    assert_eq!(result.len(), 5);

    Ok(())
}

==> v0.14.1.tar.gz: git-next/crates/core/src/git/repository/open/tests/commit_log.rs <==
use std::ops::Deref as _;

use crate::CommitCount;

//
use super::*;

#[test]
// assumes running in the git-next repo which should have main, next and dev as remote branches
fn should_return_single_item_in_commit_log_when_not_searching() -> TestResult {
    let_assert!(Ok(fs) = kxio::fs::temp());
    let gitdir = GitDir::new(fs.base().to_path_buf(), StoragePathType::Internal);
    let forge_details = given::forge_details();
    let test_repository = git::repository::test(fs.deref().clone(), forge_details);
    let_assert!(Ok(open_repository) = test_repository.open(&gitdir));
    let repo_config = &given::a_repo_config();
    let branches = repo_config.branches();
    then::create_a_commit_on_branch(&fs, &gitdir, &branches.main())?;
    then::create_a_commit_on_branch(&fs, &gitdir, &branches.main())?;
    let_assert!(Ok(result) = open_repository.commit_log(&branches.main(), &[]));
    assert_eq!(result.len(), 1);
    Ok(())
}

#[test]
// assumes running in the git-next repo which should have main, next and dev as remote branches
fn should_return_capacity_25_in_commit_log_when_searching_for_garbage() -> TestResult {
    let_assert!(Ok(fs) = kxio::fs::temp());
    let branch_name = given::a_branch_name();
    let gitdir = GitDir::new(fs.base().to_path_buf(), StoragePathType::Internal);
    let forge_details = given::forge_details().with_max_dev_commits(Some(CommitCount::from(25)));
    let_assert!(Some(max_dev_commits) = forge_details.max_dev_commits());
    assert!(**max_dev_commits >= 25);
    let test_repository = git::repository::test(fs.deref().clone(), forge_details);
    let_assert!(Ok(open_repository) = test_repository.open(&gitdir));
    for _ in [0; 25] {
        then::create_a_commit_on_branch(&fs, &gitdir, &branch_name)?;
    }
    let_assert!(Ok(result) = open_repository.commit_log(&branch_name, &[given::a_commit()]));
    assert_eq!(result.len(), 25);
    Ok(())
}

#[test]
// assumes running in the git-next repo which should have main, next and dev as remote branches
fn should_return_5_in_commit_log_when_searching_for_5th_item() -> TestResult {
    let_assert!(Ok(fs) = kxio::fs::temp(), "create temp directory");
    let branch_name = given::a_branch_name();
    let gitdir = GitDir::new(fs.base().to_path_buf(), StoragePathType::Internal);
    let forge_details = given::forge_details().with_max_dev_commits(Some(CommitCount::from(10)));
    let_assert!(Some(max_dev_commits) = forge_details.max_dev_commits());
    assert!(**max_dev_commits > 5);
    let test_repository = git::repository::test(fs.deref().clone(), forge_details);
    let_assert!(
        Ok(open_repository) = test_repository.open(&gitdir),
        "open repository"
    );
    for _ in [0; 10] {
        then::create_a_commit_on_branch(&fs, &gitdir, &branch_name)?;
    }
    // search to garbage to get all 10 items
    let_assert!(
        Ok(long_list) = open_repository.commit_log(&branch_name, &[given::a_commit()]),
        "get commit_log"
    );
    // pick the 5th item
    let search = &long_list[4]; // zero-based
                                // search for the 25th item
    let_assert!(
        Ok(result) = open_repository.commit_log(&branch_name, &[search.clone()]),
        "get commit log"
    );
    // returns
    assert_eq!(result.len(), 5);

    Ok(())
}
